MemError

Enum MemError 

pub enum MemError {
    Uninitialised {
        addr: i64,
    },
    Misaligned {
        addr: i64,
    },
    NotAByte {
        value: i64,
    },
    Device {
        addr: i64,
        reason: &'static str,
    },
    AddressOverflow {
        addr: i64,
        len: i64,
    },
}
Something went wrong with a memory access.

Variants



Uninitialised

Read of memory that was never written.

Fields

addr: i64

The offending address.



Misaligned

Access not aligned to a word boundary.

Fields

addr: i64

The offending address.



NotAByte

A tryte outside 0..=255 was written to a byte-oriented device (D-04).

Fields

value: i64

The offending value.



Device

A device rejected the access.

Fields

addr: i64

The address accessed.

reason: &'static str

What the device reported.



AddressOverflow

The access would run off the end of the address space.

Fields

addr: i64

The base address of the access.

len: i64

How many trytes the access needed.

Implementations



impl MemoryError

pub fn overshoot(&self) -> Option<i64>

For an AddressOverflow, how many trytes past the end of the address space the access would have reached. None for the other variants.